@@ -66,6 +66,7 @@ class Board:
         # draw background rectangle
         self.drawing.add(self.drawing.rect(insert=(0, 0), size=(
             str(self.width*self.scale), str(self.height*self.scale)), fill='#f0e6aa'))
+
         if(self.verbose):
             print('Milling Outline')
         self.init_file(self.files['outline'])
@@ -113,16 +114,14 @@ class Board:
             self.set_dimensions()
 
         self.scale = 3.543307 if self.unit == 'mm' else 90
-        # self.scale = 3.149608 if self.unit == 'mm' else 80
-        self.scale *= (1+scale_compensation)
 
         # initialize svg
         self.drawing = svgwrite.Drawing(
-            filename=self.output_folder+layer+'.svg', size=(self.width*self.scale, self.height*self.scale), debug=False)
+            filename=self.output_folder+layer+'.svg', size=(self.width*self.scale+offset[0], self.height*self.scale+offset[1]), debug=False)
 
         # draw background rectangle
         self.drawing.add(self.drawing.rect(insert=(0, 0), size=(
-            str(self.width*self.scale), str(self.height*self.scale)), fill='black' if color == 'white' else 'white'))
+            str(self.width*self.scale), str(self.height*self.scale+5)), fill='black' if color == 'white' else 'white'))
 
         # draw layer
         self.init_file(self.files[layer])
@@ -135,9 +134,16 @@ class Board:
         drawing = svg2rlg(self.output_folder+layer+".svg")
         if(mirrored):
             drawing.scale(-1, 1)
-            drawing.translate(float(drawing.getBounds()[0]), 0)
-        drawing.translate(offset[0], -offset[1])
-        renderPDF.drawToFile(drawing, self.output_folder +
+            drawing.translate(-self.width*self.scale *
+                              (1+scale_compensation[0])-offset[0]*2, 0)
+        # drawing.rotate(-90)
+        drawing.translate(offset[0], 0)
+        drawing.scale(1+scale_compensation[0], 1+scale_compensation[1])
+        drawing.translate(0, -offset[1])
+        d = graphics.shapes.Drawing(self.width*self.scale*(
+            1+scale_compensation[0])+offset[0], self.height*self.scale*(1+scale_compensation[1])+offset[1])
+        d.add(drawing)
+        renderPDF.drawToFile(d, self.output_folder +
                              layer+".pdf", autoSize=int(not full_page))
         os.remove(self.output_folder+layer+".svg")
 
@@ -318,7 +324,7 @@ class Board:
 
                 x_loc = g_code.find('X', x_loc+1)
             g_loc = next_code
-        path += ' z'
+        path += ' Z'
         self.drawing.add(self.drawing.path(
             d=path, stroke='none', fill=color))
 
@@ -444,14 +450,8 @@ class Board:
         index = file.find('FSLAX')
         self.x_decimals = int(file[index+6:index+7])
         self.y_decimals = int(file[index+9:index+10])
-        temp = '1'
-        for i in range(self.x_decimals):
-            temp += '0'
-        self.x_decimals = int(temp)
-        temp = '1'
-        for i in range(self.y_decimals):
-            temp += '0'
-        self.y_decimals = int(temp)
+        self.x_decimals = pow(10, int(self.x_decimals))
+        self.y_decimals = pow(10, int(self.y_decimals))
 
     def set_dimensions(self):
         file = self.files['outline']
@@ -496,12 +496,18 @@ class Board:
 
     def get_dimensions(self):
         if(self.width):
-            return [self.width, self.height, self.scale]
+            if(self.unit == 'in'):
+                return [self.width*25.4, self.height*25.4]
+            return [self.width, self.height]
         else:
             return 'Board Not Rendered'
 
+    def get_files(self):
+        return self.files
+
     def identify_files(self):
         unidentified_files = 0
+        subfolder = ''
 
         self.files = {}
         self.files['drill'] = ''
@@ -514,25 +520,32 @@ class Board:
         self.files['bottom_silk'] = ''
 
         # RS274X name schemes
-        for filename in os.listdir(self.temp_path):
-            if(not self.files['drill'] and filename[-3:].upper() == 'DRL'):
-                self.files['drill'] = self.open_file(filename)
-            elif(not self.files['outline'] and (filename[-3:].upper() == 'GKO' or filename[-3:].upper() == 'GM1')):
-                self.files['outline'] = self.open_file(filename)
-            elif(not self.files['top_copper'] and filename[-3:].upper() == 'GTL'):
-                self.files['top_copper'] = self.open_file(filename)
-            elif(not self.files['top_mask'] and filename[-3:].upper() == 'GTS'):
-                self.files['top_mask'] = self.open_file(filename)
-            elif(not self.files['top_silk'] and filename[-3:].upper() == 'GTO'):
-                self.files['top_silk'] = self.open_file(filename)
-            elif(not self.files['bottom_copper'] and filename[-3:].upper() == 'GBL'):
-                self.files['bottom_copper'] = self.open_file(filename)
-            elif(not self.files['bottom_mask'] and filename[-3:].upper() == 'GBS'):
-                self.files['bottom_mask'] = self.open_file(filename)
-            elif(not self.files['bottom_silk'] and filename[-3:].upper() == 'GBO'):
-                self.files['bottom_silk'] = self.open_file(filename)
-            else:
-                unidentified_files += 1
+        for root, dirs, files in os.walk(self.temp_path):
+            for filename in files:
+                if(not self.files['drill'] and filename[-3:].upper() == 'DRL'):
+                    self.files['drill'] = open(root+'/'+filename, 'r').read()
+                elif(not self.files['outline'] and (filename[-3:].upper() == 'GKO' or filename[-3:].upper() == 'GM1')):
+                    self.files['outline'] = open(root+'/'+filename, 'r').read()
+                elif(not self.files['top_copper'] and filename[-3:].upper() == 'GTL'):
+                    self.files['top_copper'] = open(
+                        root+'/'+filename, 'r').read()
+                elif(not self.files['top_mask'] and filename[-3:].upper() == 'GTS'):
+                    self.files['top_mask'] = open(
+                        root+'/'+filename, 'r').read()
+                elif(not self.files['top_silk'] and filename[-3:].upper() == 'GTO'):
+                    self.files['top_silk'] = open(
+                        root+'/'+filename, 'r').read()
+                elif(not self.files['bottom_copper'] and filename[-3:].upper() == 'GBL'):
+                    self.files['bottom_copper'] = open(
+                        root+'/'+filename, 'r').read()
+                elif(not self.files['bottom_mask'] and filename[-3:].upper() == 'GBS'):
+                    self.files['bottom_mask'] = open(
+                        root+'/'+filename, 'r').read()
+                elif(not self.files['bottom_silk'] and filename[-3:].upper() == 'GBO'):
+                    self.files['bottom_silk'] = open(
+                        root+'/'+filename, 'r').read()
+                else:
+                    unidentified_files += 1
 
         shutil.rmtree(self.temp_path)
 
@@ -540,7 +553,6 @@ class Board:
             if(self.verbose):
                 print('Files Loaded\nUnidentified Files: ' +
                       str(unidentified_files))
-
         else:
             print('Error identifying files')
 
